#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.eog_postasa_plugin"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[2122]; const double alignment; void * const ptr;}  eog_postasa_plugin_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0010, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0005, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 
  0260, 0267, 0044, 0060, 0004, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 
  0010, 0001, 0000, 0000, 0014, 0001, 0000, 0000, 0101, 0146, 0150, 0220, 0006, 0000, 0000, 0000, 
  0014, 0001, 0000, 0000, 0022, 0000, 0166, 0000, 0040, 0001, 0000, 0000, 0255, 0004, 0000, 0000, 
  0232, 0127, 0122, 0236, 0000, 0000, 0000, 0000, 0255, 0004, 0000, 0000, 0004, 0000, 0114, 0000, 
  0264, 0004, 0000, 0000, 0270, 0004, 0000, 0000, 0253, 0371, 0142, 0034, 0002, 0000, 0000, 0000, 
  0270, 0004, 0000, 0000, 0010, 0000, 0114, 0000, 0300, 0004, 0000, 0000, 0304, 0004, 0000, 0000, 
  0113, 0120, 0220, 0013, 0005, 0000, 0000, 0000, 0304, 0004, 0000, 0000, 0004, 0000, 0114, 0000, 
  0310, 0004, 0000, 0000, 0314, 0004, 0000, 0000, 0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 
  0314, 0004, 0000, 0000, 0001, 0000, 0114, 0000, 0320, 0004, 0000, 0000, 0324, 0004, 0000, 0000, 
  0065, 0160, 0144, 0011, 0003, 0000, 0000, 0000, 0324, 0004, 0000, 0000, 0010, 0000, 0114, 0000, 
  0334, 0004, 0000, 0000, 0344, 0004, 0000, 0000, 0177, 0234, 0014, 0010, 0006, 0000, 0000, 0000, 
  0344, 0004, 0000, 0000, 0021, 0000, 0166, 0000, 0370, 0004, 0000, 0000, 0111, 0010, 0000, 0000, 
  0147, 0156, 0157, 0155, 0145, 0057, 0000, 0000, 0002, 0000, 0000, 0000, 0160, 0157, 0163, 0164, 
  0141, 0163, 0141, 0055, 0165, 0160, 0154, 0157, 0141, 0144, 0163, 0056, 0165, 0151, 0000, 0000, 
  0022, 0022, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0130, 0133, 0157, 0332, 0060, 
  0024, 0176, 0357, 0257, 0310, 0374, 0072, 0061, 0012, 0123, 0373, 0060, 0005, 0127, 0153, 0245, 
  0266, 0017, 0225, 0066, 0255, 0335, 0366, 0030, 0071, 0311, 0201, 0170, 0230, 0070, 0263, 0035, 
  0010, 0373, 0365, 0073, 0211, 0041, 0100, 0223, 0346, 0002, 0335, 0244, 0111, 0173, 0043, 0366, 
  0271, 0174, 0347, 0362, 0235, 0143, 0341, 0136, 0145, 0013, 0341, 0054, 0101, 0151, 0056, 0343, 
  0011, 0031, 0275, 0073, 0047, 0127, 0364, 0314, 0345, 0261, 0001, 0065, 0145, 0001, 0120, 0127, 
  0301, 0317, 0224, 0053, 0320, 0216, 0340, 0376, 0204, 0314, 0314, 0374, 0055, 0331, 0311, 0217, 
  0337, 0215, 0056, 0311, 0220, 0272, 0157, 0006, 0003, 0247, 0324, 0031, 0304, 0154, 0301, 0343, 
  0331, 0040, 0221, 0202, 0007, 0153, 0047, 0121, 0362, 0007, 0004, 0146, 0260, 0342, 0041, 0070, 
  0203, 0001, 0165, 0245, 0237, 0177, 0073, 0201, 0140, 0132, 0117, 0310, 0235, 0231, 0077, 0160, 
  0155, 0036, 0215, 0124, 0100, 0034, 0036, 0116, 0110, 0232, 0010, 0311, 0102, 0355, 0351, 0342, 
  0210, 0272, 0201, 0024, 0351, 0042, 0326, 0326, 0213, 0375, 0310, 0135, 0200, 0143, 0242, 0164, 
  0341, 0307, 0214, 0213, 0302, 0254, 0275, 0161, 0314, 0072, 0001, 0264, 0032, 0316, 0077, 0363, 
  0314, 0117, 0247, 0133, 0164, 0373, 0172, 0123, 0056, 0040, 0141, 0046, 0252, 0252, 0315, 0202, 
  0210, 0051, 0246, 0024, 0133, 0327, 0351, 0151, 0376, 0013, 0372, 0352, 0330, 0140, 0060, 0026, 
  0146, 0122, 0135, 0243, 0234, 0142, 0332, 0352, 0364, 0002, 0026, 0007, 0040, 0004, 0363, 0105, 
  0215, 0313, 0273, 0117, 0105, 0012, 0033, 0374, 0055, 0100, 0153, 0066, 0153, 0105, 0073, 0054, 
  0163, 0073, 0264, 0125, 0251, 0251, 0316, 0167, 0036, 0207, 0162, 0165, 0130, 0232, 0225, 0075, 
  0243, 0056, 0026, 0067, 0001, 0145, 0326, 0116, 0356, 0174, 0102, 0260, 0306, 0046, 0362, 0362, 
  0226, 0001, 0155, 0010, 0275, 0270, 0070, 0167, 0207, 0133, 0221, 0212, 0160, 0004, 0174, 0026, 
  0231, 0235, 0364, 0370, 0120, 0072, 0210, 0270, 0010, 0153, 0360, 0334, 0137, 0313, 0314, 0242, 
  0211, 0174, 0231, 0215, 0252, 0040, 0226, 0134, 0163, 0114, 0033, 0241, 0117, 0052, 0205, 0056, 
  0026, 0277, 0225, 0026, 0227, 0150, 0161, 0334, 0303, 0342, 0063, 0071, 0251, 0070, 0304, 0130, 
  0151, 0344, 0006, 0241, 0110, 0022, 0303, 0003, 0046, 0272, 0040, 0170, 0140, 0076, 0210, 0303, 
  0024, 0213, 0342, 0250, 0065, 0151, 0115, 0011, 0356, 0012, 0073, 0143, 0202, 0317, 0342, 0146, 
  0133, 0353, 0204, 0205, 0204, 0216, 0232, 0104, 0054, 0142, 0307, 0050, 0026, 0153, 0301, 0114, 
  0336, 0272, 0250, 0007, 0232, 0320, 0257, 0066, 0246, 0017, 0373, 0312, 0145, 0303, 0045, 0054, 
  0230, 0343, 0270, 0250, 0230, 0203, 0054, 0141, 0061, 0372, 0274, 0145, 0102, 0067, 0241, 0107, 
  0066, 0213, 0166, 0251, 0104, 0152, 0156, 0353, 0162, 0020, 0302, 0260, 0364, 0076, 0334, 0324, 
  0346, 0245, 0022, 0075, 0006, 0112, 0012, 0001, 0341, 0076, 0035, 0364, 0346, 0314, 0322, 0141, 
  0164, 0174, 0343, 0040, 0333, 0275, 0251, 0014, 0122, 0335, 0052, 0031, 0131, 0237, 0076, 0123, 
  0236, 0235, 0257, 0204, 0306, 0200, 0255, 0326, 0324, 0006, 0125, 0025, 0226, 0032, 0271, 0300, 
  0076, 0015, 0072, 0321, 0203, 0303, 0052, 0221, 0312, 0154, 0050, 0262, 0371, 0072, 0041, 0132, 
  0334, 0046, 0070, 0111, 0275, 0205, 0014, 0121, 0026, 0373, 0270, 0033, 0113, 0237, 0024, 0100, 
  0016, 0345, 0220, 0046, 0071, 0234, 0277, 0221, 0367, 0034, 0054, 0266, 0331, 0301, 0156, 0352, 
  0203, 0372, 0246, 0030, 0264, 0026, 0173, 0276, 0177, 0074, 0234, 0274, 0125, 0334, 0206, 0033, 
  0104, 0135, 0107, 0241, 0133, 0324, 0151, 0200, 0267, 0045, 0113, 0327, 0221, 0167, 0203, 0273, 
  0345, 0013, 0304, 0041, 0050, 0120, 0233, 0105, 0131, 0100, 0053, 0127, 0252, 0227, 0157, 0237, 
  0174, 0105, 0060, 0143, 0024, 0367, 0123, 0003, 0172, 0357, 0367, 0226, 0124, 0126, 0063, 0247, 
  0124, 0171, 0105, 0367, 0176, 0353, 0166, 0132, 0355, 0003, 0171, 0202, 0314, 0354, 0062, 0224, 
  0157, 0150, 0213, 0242, 0032, 0255, 0020, 0074, 0311, 0173, 0210, 0120, 0134, 0254, 0312, 0324, 
  0316, 0225, 0046, 0340, 0046, 0367, 0104, 0107, 0355, 0260, 0113, 0153, 0155, 0161, 0324, 0325, 
  0271, 0350, 0362, 0332, 0072, 0343, 0015, 0016, 0035, 0102, 0247, 0074, 0203, 0260, 0161, 0266, 
  0341, 0275, 0127, 0154, 0125, 0102, 0057, 0233, 0206, 0357, 0313, 0235, 0363, 0210, 0050, 0372, 
  0266, 0304, 0256, 0022, 0066, 0206, 0016, 0275, 0140, 0123, 0072, 0376, 0303, 0051, 0305, 0060, 
  0146, 0070, 0076, 0164, 0175, 0132, 0361, 0331, 0271, 0115, 0326, 0350, 0330, 0154, 0025, 0017, 
  0265, 0336, 0024, 0332, 0300, 0172, 0016, 0262, 0013, 0207, 0122, 0134, 0134, 0204, 0276, 0077, 
  0110, 0134, 0175, 0162, 0057, 0216, 0110, 0156, 0217, 0203, 0227, 0026, 0361, 0156, 0165, 0216, 
  0216, 0133, 0235, 0207, 0057, 0266, 0361, 0053, 0274, 0330, 0356, 0257, 0123, 0143, 0144, 0274, 
  0147, 0267, 0370, 0356, 0371, 0036, 0174, 0116, 0112, 0014, 0250, 0140, 0145, 0313, 0053, 0147, 
  0055, 0123, 0203, 0013, 0140, 0235, 0233, 0304, 0372, 0167, 0301, 0153, 0341, 0132, 0254, 0366, 
  0145, 0357, 0131, 0304, 0244, 0307, 0053, 0352, 0246, 0120, 0164, 0036, 0101, 0240, 0361, 0306, 
  0261, 0361, 0372, 0353, 0117, 0101, 0000, 0174, 0011, 0332, 0013, 0141, 0312, 0122, 0141, 0252, 
  0012, 0377, 0332, 0173, 0256, 0246, 0044, 0114, 0234, 0120, 0226, 0217, 0102, 0374, 0257, 0110, 
  0247, 0061, 0321, 0143, 0340, 0234, 0237, 0150, 0351, 0225, 0043, 0144, 0141, 0330, 0076, 0040, 
  0166, 0350, 0307, 0247, 0346, 0241, 0247, 0277, 0256, 0331, 0252, 0036, 0354, 0376, 0357, 0071, 
  0373, 0015, 0225, 0057, 0220, 0063, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0145, 0157, 0147, 
  0057, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 0160, 0154, 0165, 0147, 0151, 0156, 0163, 0057, 
  0006, 0000, 0000, 0000, 0157, 0162, 0147, 0057, 0000, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 
  0004, 0000, 0000, 0000, 0160, 0157, 0163, 0164, 0141, 0163, 0141, 0057, 0007, 0000, 0000, 0000, 
  0001, 0000, 0000, 0000, 0160, 0157, 0163, 0164, 0141, 0163, 0141, 0055, 0143, 0157, 0156, 0146, 
  0151, 0147, 0056, 0165, 0151, 0000, 0000, 0000, 0377, 0022, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0355, 0130, 0315, 0162, 0233, 0060, 0020, 0276, 0347, 0051, 0250, 0256, 0035, 0202, 
  0161, 0223, 0066, 0323, 0301, 0164, 0246, 0077, 0361, 0045, 0207, 0314, 0064, 0231, 0036, 0065, 
  0002, 0326, 0240, 0106, 0226, 0250, 0044, 0354, 0220, 0227, 0350, 0261, 0357, 0327, 0047, 0251, 
  0000, 0033, 0333, 0140, 0103, 0352, 0072, 0156, 0072, 0323, 0243, 0304, 0267, 0277, 0337, 0356, 
  0112, 0302, 0173, 0167, 0077, 0145, 0326, 0014, 0244, 0242, 0202, 0217, 0220, 0173, 0072, 0100, 
  0026, 0360, 0120, 0104, 0224, 0307, 0043, 0164, 0173, 0163, 0151, 0137, 0240, 0167, 0376, 0211, 
  0367, 0302, 0266, 0255, 0061, 0160, 0220, 0104, 0103, 0144, 0315, 0251, 0116, 0254, 0230, 0221, 
  0010, 0254, 0127, 0247, 0356, 0305, 0251, 0153, 0331, 0266, 0001, 0121, 0256, 0101, 0116, 0110, 
  0010, 0276, 0047, 0341, 0133, 0106, 0045, 0050, 0213, 0321, 0140, 0204, 0142, 0175, 0367, 0022, 
  0255, 0254, 0030, 0231, 0063, 0344, 0370, 0236, 0010, 0276, 0102, 0250, 0255, 0220, 0021, 0245, 
  0106, 0150, 0254, 0357, 0076, 0122, 0302, 0104, 0214, 0054, 0032, 0215, 0120, 0052, 0224, 0046, 
  0212, 0140, 0263, 0101, 0071, 0216, 0252, 0057, 0276, 0227, 0112, 0221, 0202, 0324, 0271, 0305, 
  0311, 0024, 0106, 0050, 0001, 0032, 0047, 0032, 0027, 0346, 0100, 0151, 0344, 0273, 0347, 0003, 
  0317, 0131, 0142, 0132, 0350, 0220, 0160, 0074, 0021, 0141, 0246, 0220, 0177, 0111, 0230, 0202, 
  0016, 0150, 0040, 0144, 0004, 0022, 0317, 0151, 0244, 0023, 0344, 0237, 0167, 0040, 0065, 0325, 
  0014, 0220, 0245, 0045, 0341, 0212, 0021, 0115, 0002, 0146, 0066, 0163, 0060, 0066, 0256, 0151, 
  0150, 0042, 0370, 0002, 0201, 0165, 0125, 0004, 0321, 0241, 0303, 0144, 0212, 0076, 0024, 0222, 
  0375, 0216, 0351, 0074, 0005, 0234, 0230, 0124, 0043, 0277, 0112, 0112, 0007, 0066, 0002, 0006, 
  0172, 0207, 0332, 0060, 0241, 0054, 0262, 0112, 0312, 0070, 0141, 0166, 0271, 0034, 0241, 0131, 
  0040, 0356, 0321, 0026, 0146, 0336, 0233, 0355, 0222, 0226, 0312, 0046, 0136, 0340, 0032, 0366, 
  0146, 0124, 0321, 0322, 0332, 0215, 0314, 0340, 0060, 0074, 0010, 0111, 0201, 0153, 0242, 0115, 
  0341, 0040, 0337, 0124, 0220, 0066, 0071, 0145, 0035, 0170, 0225, 0222, 0320, 0324, 0056, 0362, 
  0207, 0375, 0301, 0222, 0260, 0120, 0213, 0211, 0004, 0262, 0065, 0346, 0114, 0153, 0301, 0353, 
  0310, 0203, 0162, 0211, 0217, 0025, 0070, 0043, 0271, 0310, 0064, 0126, 0072, 0057, 0364, 0002, 
  0217, 0132, 0361, 0354, 0164, 0271, 0362, 0327, 0330, 0012, 0201, 0341, 0312, 0155, 0264, 0105, 
  0177, 0000, 0154, 0153, 0331, 0342, 0017, 0245, 0144, 0207, 0157, 0231, 0002, 0274, 0114, 0136, 
  0232, 0002, 0221, 0205, 0100, 0177, 0110, 0173, 0144, 0251, 0007, 0051, 0041, 0004, 0072, 0003, 
  0205, 0043, 0230, 0220, 0214, 0351, 0136, 0201, 0302, 0363, 0214, 0233, 0316, 0146, 0224, 0157, 
  0161, 0304, 0251, 0062, 0152, 0304, 0110, 0170, 0147, 0312, 0250, 0045, 0017, 0367, 0051, 0341, 
  0121, 0177, 0250, 0023, 0312, 0130, 0077, 0312, 0314, 0070, 0132, 0125, 0366, 0306, 0324, 0162, 
  0152, 0353, 0316, 0202, 0350, 0307, 0360, 0135, 0015, 0312, 0075, 0350, 0356, 0033, 0116, 0377, 
  0331, 0076, 0064, 0333, 0156, 0067, 0333, 0007, 0366, 0253, 0047, 0111, 0205, 0021, 0134, 0234, 
  0052, 0255, 0051, 0163, 0350, 0152, 0035, 0113, 0032, 0255, 0327, 0152, 0134, 0254, 0217, 0061, 
  0113, 0245, 0230, 0343, 0372, 0140, 0170, 0335, 0245, 0123, 0260, 0154, 0312, 0127, 0130, 0167, 
  0370, 0230, 0251, 0173, 0125, 0365, 0126, 0021, 0230, 0251, 0070, 0131, 0250, 0302, 0125, 0277, 
  0035, 0347, 0240, 0330, 0331, 0331, 0267, 0013, 0157, 0336, 0356, 0337, 0043, 0015, 0364, 0224, 
  0303, 0124, 0160, 0032, 0026, 0027, 0243, 0030, 0114, 0007, 0326, 0001, 0233, 0123, 0132, 0346, 
  0035, 0222, 0367, 0204, 0321, 0270, 0125, 0373, 0175, 0225, 0316, 0140, 0242, 0061, 0321, 0232, 
  0204, 0111, 0243, 0354, 0232, 0327, 0042, 0221, 0156, 0307, 0075, 0276, 0074, 0327, 0150, 0114, 
  0315, 0336, 0334, 0334, 0000, 0237, 0007, 0215, 0327, 0013, 0157, 0236, 0220, 0306, 0072, 0340, 
  0147, 0104, 0243, 0273, 0037, 0215, 0237, 0212, 0010, 0032, 0335, 0130, 0106, 0325, 0246, 0261, 
  0274, 0335, 0257, 0036, 0017, 0303, 0263, 0301, 0121, 0317, 0263, 0144, 0071, 0307, 0173, 0160, 
  0224, 0057, 0154, 0343, 0060, 0041, 0022, 0371, 0077, 0177, 0174, 0337, 0077, 0373, 0356, 0323, 
  0066, 0321, 0132, 0366, 0067, 0153, 0352, 0237, 0315, 0176, 0151, 0231, 0062, 0252, 0363, 0376, 
  0046, 0376, 0053, 0114, 0271, 0177, 0074, 0356, 0252, 0343, 0170, 0012, 0112, 0221, 0030, 0216, 
  0062, 0355, 0362, 0224, 0230, 0314, 0277, 0171, 0372, 0041, 0062, 0354, 0300, 0055, 0036, 0367, 
  0303, 0147, 0165, 0033, 0373, 0355, 0113, 0342, 0162, 0243, 0272, 0242, 0333, 0325, 0104, 0127, 
  0215, 0265, 0045, 0101, 0245, 0202, 0053, 0143, 0141, 0200, 0374, 0215, 0247, 0241, 0347, 0154, 
  0040, 0167, 0013, 0332, 0056, 0362, 0327, 0037, 0031, 0055, 0101, 0247, 0351, 0102, 0355, 0143, 
  0253, 0370, 0076, 0323, 0007, 0030, 0113, 0221, 0245, 0125, 0001, 0226, 0023, 0002, 0053, 0263, 
  0031, 0227, 0233, 0276, 0127, 0353, 0130, 0270, 0121, 0237, 0162, 0353, 0003, 0335, 0151, 0174, 
  0156, 0114, 0034, 0363, 0331, 0151, 0373, 0342, 0254, 0176, 0123, 0235, 0374, 0002, 0213, 0302, 
  0376, 0057, 0000, 0050, 0165, 0165, 0141, 0171, 0051
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[2122]; const double alignment; void * const ptr;}  eog_postasa_plugin_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\000\001\000\000\000\000\000\050\010\000\000\000"
  "\000\000\000\000\001\000\000\000\002\000\000\000\003\000\000\000"
  "\005\000\000\000\006\000\000\000\007\000\000\000\007\000\000\000"
  "\260\267\044\060\004\000\000\000\000\001\000\000\006\000\114\000"
  "\010\001\000\000\014\001\000\000\101\146\150\220\006\000\000\000"
  "\014\001\000\000\022\000\166\000\040\001\000\000\255\004\000\000"
  "\232\127\122\236\000\000\000\000\255\004\000\000\004\000\114\000"
  "\264\004\000\000\270\004\000\000\253\371\142\034\002\000\000\000"
  "\270\004\000\000\010\000\114\000\300\004\000\000\304\004\000\000"
  "\113\120\220\013\005\000\000\000\304\004\000\000\004\000\114\000"
  "\310\004\000\000\314\004\000\000\324\265\002\000\377\377\377\377"
  "\314\004\000\000\001\000\114\000\320\004\000\000\324\004\000\000"
  "\065\160\144\011\003\000\000\000\324\004\000\000\010\000\114\000"
  "\334\004\000\000\344\004\000\000\177\234\014\010\006\000\000\000"
  "\344\004\000\000\021\000\166\000\370\004\000\000\111\010\000\000"
  "\147\156\157\155\145\057\000\000\002\000\000\000\160\157\163\164"
  "\141\163\141\055\165\160\154\157\141\144\163\056\165\151\000\000"
  "\022\022\000\000\001\000\000\000\170\332\355\130\133\157\332\060"
  "\024\176\357\257\310\374\072\061\012\123\373\060\005\127\153\245"
  "\266\017\225\066\255\335\366\030\071\311\201\170\230\070\263\035"
  "\010\373\365\073\211\041\100\223\346\002\335\244\111\173\043\366"
  "\271\174\347\362\235\143\341\136\145\013\341\054\101\151\056\343"
  "\011\031\275\073\047\127\364\314\345\261\001\065\145\001\120\127"
  "\301\317\224\053\320\216\340\376\204\314\314\374\055\331\311\217"
  "\337\215\056\311\220\272\157\006\003\247\324\031\304\154\301\343"
  "\331\040\221\202\007\153\047\121\362\007\004\146\260\342\041\070"
  "\203\001\165\245\237\177\073\201\140\132\117\310\235\231\077\160"
  "\155\036\215\124\100\034\036\116\110\232\010\311\102\355\351\342"
  "\210\272\201\024\351\042\326\326\213\375\310\135\200\143\242\164"
  "\341\307\214\213\302\254\275\161\314\072\001\264\032\316\077\363"
  "\314\117\247\133\164\373\172\123\056\040\141\046\252\252\315\202"
  "\210\051\246\024\133\327\351\151\376\013\372\352\330\140\060\026"
  "\146\122\135\243\234\142\332\352\364\002\026\007\040\004\363\105"
  "\215\313\273\117\105\012\033\374\055\100\153\066\153\105\073\054"
  "\163\073\264\125\251\251\316\167\036\207\162\165\130\232\225\075"
  "\243\056\026\067\001\145\326\116\356\174\102\260\306\046\362\362"
  "\226\001\155\010\275\270\070\167\207\133\221\212\160\004\174\026"
  "\231\235\364\370\120\072\210\270\010\153\360\334\137\313\314\242"
  "\211\174\231\215\252\040\226\134\163\114\033\241\117\052\205\056"
  "\026\277\225\026\227\150\161\334\303\342\063\071\251\070\304\130"
  "\151\344\006\241\110\022\303\003\046\272\040\170\140\076\210\303"
  "\024\213\342\250\065\151\115\011\356\012\073\143\202\317\342\146"
  "\133\353\204\205\204\216\232\104\054\142\307\050\026\153\301\114"
  "\336\272\250\007\232\320\257\066\246\017\373\312\145\303\045\054"
  "\230\343\270\250\230\203\054\141\061\372\274\145\102\067\241\107"
  "\066\213\166\251\104\152\156\353\162\020\302\260\364\076\334\324"
  "\346\245\022\075\006\112\012\001\341\076\035\364\346\314\322\141"
  "\164\174\343\040\333\275\251\014\122\335\052\031\131\237\076\123"
  "\236\235\257\204\306\200\255\326\324\006\125\025\226\032\271\300"
  "\076\015\072\321\203\303\052\221\312\154\050\262\371\072\041\132"
  "\334\046\070\111\275\205\014\121\026\373\270\033\113\237\024\100"
  "\016\345\220\046\071\234\277\221\367\034\054\266\331\301\156\352"
  "\203\372\246\030\264\026\173\276\177\074\234\274\125\334\206\033"
  "\104\135\107\241\133\324\151\200\267\045\113\327\221\167\203\273"
  "\345\013\304\041\050\120\233\105\131\100\053\127\252\227\157\237"
  "\174\105\060\143\024\367\123\003\172\357\367\226\124\126\063\247"
  "\124\171\105\367\176\353\166\132\355\003\171\202\314\354\062\224"
  "\157\150\213\242\032\255\020\074\311\173\210\120\134\254\312\324"
  "\316\225\046\340\046\367\104\107\355\260\113\153\155\161\324\325"
  "\271\350\362\332\072\343\015\016\035\102\247\074\203\260\161\266"
  "\341\275\127\154\125\102\057\233\206\357\313\235\363\210\050\372"
  "\266\304\256\022\066\206\016\275\140\123\072\376\303\051\305\060"
  "\146\070\076\164\175\132\361\331\271\115\326\350\330\154\025\017"
  "\265\336\024\332\300\172\016\262\013\207\122\134\134\204\276\077"
  "\110\134\175\162\057\216\110\156\217\203\227\026\361\156\165\216"
  "\216\133\235\207\057\266\361\053\274\330\356\257\123\143\144\274"
  "\147\267\370\356\371\036\174\116\112\014\250\140\145\313\053\147"
  "\055\123\203\013\140\235\233\304\372\167\301\153\341\132\254\366"
  "\145\357\131\304\244\307\053\352\246\120\164\036\101\240\361\306"
  "\261\361\372\353\117\101\000\174\011\332\013\141\312\122\141\252"
  "\012\377\332\173\256\246\044\114\234\120\226\217\102\374\257\110"
  "\247\061\321\143\340\234\237\150\351\225\043\144\141\330\076\040"
  "\166\350\307\247\346\241\247\277\256\331\252\036\354\376\357\071"
  "\373\015\225\057\220\063\000\050\165\165\141\171\051\145\157\147"
  "\057\000\000\000\003\000\000\000\160\154\165\147\151\156\163\057"
  "\006\000\000\000\157\162\147\057\000\000\000\000\057\000\000\000"
  "\004\000\000\000\160\157\163\164\141\163\141\057\007\000\000\000"
  "\001\000\000\000\160\157\163\164\141\163\141\055\143\157\156\146"
  "\151\147\056\165\151\000\000\000\377\022\000\000\001\000\000\000"
  "\170\332\355\130\315\162\233\060\020\276\347\051\250\256\035\202"
  "\161\223\066\323\301\164\246\077\361\045\207\314\064\231\036\065"
  "\002\326\240\106\226\250\044\354\220\227\350\261\357\327\047\251"
  "\000\033\333\140\103\352\072\156\072\323\243\304\267\277\337\356"
  "\112\302\173\167\077\145\326\014\244\242\202\217\220\173\072\100"
  "\026\360\120\104\224\307\043\164\173\163\151\137\240\167\376\211"
  "\367\302\266\255\061\160\220\104\103\144\315\251\116\254\230\221"
  "\010\254\127\247\356\305\251\153\331\266\001\121\256\101\116\110"
  "\010\276\047\341\133\106\045\050\213\321\140\204\142\175\367\022"
  "\255\254\030\231\063\344\370\236\010\276\102\250\255\220\021\245"
  "\106\150\254\357\076\122\302\104\214\054\032\215\120\052\224\046"
  "\212\140\263\101\071\216\252\057\276\227\112\221\202\324\271\305"
  "\311\024\106\050\001\032\047\032\027\346\100\151\344\273\347\003"
  "\317\131\142\132\350\220\160\074\021\141\246\220\177\111\230\202"
  "\016\150\040\144\004\022\317\151\244\023\344\237\167\040\065\325"
  "\014\220\245\045\341\212\021\115\002\146\066\163\060\066\256\151"
  "\150\042\370\002\201\165\125\004\321\241\303\144\212\076\024\222"
  "\375\216\351\074\005\234\230\124\043\277\112\112\007\066\002\006"
  "\172\207\332\060\241\054\262\112\312\070\141\166\271\034\241\131"
  "\040\356\321\026\146\336\233\355\222\226\312\046\136\340\032\366"
  "\146\124\321\322\332\215\314\340\060\074\010\111\201\153\242\115"
  "\341\040\337\124\220\066\071\145\035\170\225\222\320\324\056\362"
  "\207\375\301\222\260\120\213\211\004\262\065\346\114\153\301\353"
  "\310\203\162\211\217\025\070\043\271\310\064\126\072\057\364\002"
  "\217\132\361\354\164\271\362\327\330\012\201\341\312\155\264\105"
  "\177\000\154\153\331\342\017\245\144\207\157\231\002\274\114\136"
  "\232\002\221\205\100\177\110\173\144\251\007\051\041\004\072\003"
  "\205\043\230\220\214\351\136\201\302\363\214\233\316\146\224\157"
  "\161\304\251\062\152\304\110\170\147\312\250\045\017\367\051\341"
  "\121\177\250\023\312\130\077\312\314\070\132\125\366\306\324\162"
  "\152\353\316\202\350\307\360\135\015\312\075\350\356\033\116\377"
  "\331\076\064\333\156\067\333\007\366\253\047\111\205\021\134\234"
  "\052\255\051\163\350\152\035\113\032\255\327\152\134\254\217\061"
  "\113\245\230\343\372\140\170\335\245\123\260\154\312\127\130\167"
  "\370\230\251\173\125\365\126\021\230\251\070\131\250\302\125\277"
  "\035\347\240\330\331\331\267\013\157\336\356\337\043\015\364\224"
  "\303\124\160\032\026\027\243\030\114\007\326\001\233\123\132\346"
  "\035\222\367\204\321\270\125\373\175\225\316\140\242\061\321\232"
  "\204\111\243\354\232\327\042\221\156\307\075\276\074\327\150\114"
  "\315\336\334\334\000\237\007\215\327\013\157\236\220\306\072\340"
  "\147\104\243\273\037\215\237\212\010\032\335\130\106\325\246\261"
  "\274\335\257\036\017\303\263\301\121\317\263\144\071\307\173\160"
  "\224\057\154\343\060\041\022\371\077\177\174\337\077\373\356\323"
  "\066\321\132\366\067\153\352\237\315\176\151\231\062\252\363\376"
  "\046\376\053\114\271\177\074\356\252\343\170\012\112\221\030\216"
  "\062\355\362\224\230\314\277\171\372\041\062\354\300\055\036\367"
  "\303\147\165\033\373\355\113\342\162\243\272\242\333\325\104\127"
  "\215\265\045\101\245\202\053\143\141\200\374\215\247\241\347\154"
  "\040\167\013\332\056\362\327\037\031\055\101\247\351\102\355\143"
  "\253\370\076\323\007\030\113\221\245\125\001\226\023\002\053\263"
  "\031\227\233\276\127\353\130\270\121\237\162\353\003\335\151\174"
  "\156\114\034\363\331\151\373\342\254\176\123\235\374\002\213\302"
  "\376\057\000\050\165\165\141\171\051" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { eog_postasa_plugin_resource_data.data, sizeof (eog_postasa_plugin_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_GNUC_INTERNAL
GResource *eog_postasa_plugin_get_resource (void);
GResource *eog_postasa_plugin_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(eog_postasa_pluginresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(eog_postasa_pluginresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(eog_postasa_pluginresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(eog_postasa_pluginresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void eog_postasa_pluginresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void eog_postasa_pluginresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
